@@ -53,6 +53,7 @@ from eutester import eulogger
 from eutester.taggedresource import TaggedResource
 from random import randint
 import sshconnection
+import sys
 import os
 import re
 import time
@@ -203,7 +204,8 @@ class EuInstance(Instance, TaggedResource):
         
         
     
-    def reset_ssh_connection(self):
+    def reset_ssh_connection(self, timeout=None):
+        timeout = timeout or self.timeout
         self.debug('reset_ssh_connection for:'+str(self.id))
         if ((self.keypath is not None) or ((self.username is not None)and(self.password is not None))):
             if self.ssh is not None:
@@ -215,7 +217,7 @@ class EuInstance(Instance, TaggedResource):
                                                     keypath=self.keypath,          
                                                     password=self.password, 
                                                     username=self.username, 
-                                                    timeout=self.timeout, 
+                                                    timeout=timeout,
                                                     retry=self.retry,
                                                     debugmethod=self.debugmethod,
                                                     verbose=self.verbose)
@@ -230,6 +232,7 @@ class EuInstance(Instance, TaggedResource):
         timeout - optional - time in seconds to wait for connection before failure
         '''
         self.debug("Attempting to reconnect_to_instance:"+self.id)
+        attempts = 0
         if ((self.keypath is not None) or ((self.username is not None)and(self.password is not None))):
             start = time.time()
             elapsed = 0
@@ -237,6 +240,7 @@ class EuInstance(Instance, TaggedResource):
                 self.ssh.close()
             self.ssh = None
             while (elapsed < timeout):
+                attempts += 1
                 try:
                     self.reset_ssh_connection()
                     self.debug('Try some sys...')
@@ -244,13 +248,14 @@ class EuInstance(Instance, TaggedResource):
                 except Exception, se:
                     self.debug('Caught exception attempting to reconnect ssh:'+ str(se))
                     elapsed = int(time.time()-start)
-                    self.debug('retrying ssh connection, elapsed:'+str(elapsed)+'/'+str(timeout))
+                    self.debug('connect_to_instance: Attempts:'+str(attempts)+', elapsed:'+str(elapsed)+'/'+str(timeout))
                     time.sleep(5)
                     pass
                 else:
                     break
             if self.ssh is None:
-                raise Exception(str(self.id)+":Failed establishing ssh connection in reconnect")
+                raise Exception(str(self.id)+":Failed establishing ssh connection to instance, elapsed:"+str(elapsed)+
+                                "/"+str(timeout))
         else:
             self.debug("keypath or username/password need to be populated for ssh connection") 
     
@@ -483,7 +488,7 @@ class EuInstance(Instance, TaggedResource):
         bad_vol_ids = []
         start = time.time()
         if verify_vols:
-            self.debug('Checking euinstance attached volume state is in sync with clouds...')
+            self.debug('Checking euinstance attached volumes states are in sync with clouds...')
             for vol in self.attached_vols:
                 try:
                     self.verify_attached_vol_cloud_status(vol)
@@ -494,6 +499,7 @@ class EuInstance(Instance, TaggedResource):
         self.tester.terminate_single_instance(self, timeout=timeout)
         elapsed = int(time.time()-start)
         if self.bdm_vol:
+            #check for bfebs backing volume state
             if self.block_device_mapping.current_value.delete_on_termination:
                 vol_state='deleted'
             else:
@@ -505,18 +511,26 @@ class EuInstance(Instance, TaggedResource):
                 self.bdm_vol.update()
                 time.sleep(5)
         if verify_vols:
-            for vol in self.attached_vols:
-                if vol in bad_vols:
-                    continue
-                while (vol.status != 'available') and (elapsed < timeout):
-                    time.sleep(5)
-                    vol.update()
+            self.debug('Waiting for attached volumes to go to available...')
+            while self.attached_vols and (elapsed < timeout): 
+                for vol in self.attached_vols:
                     elapsed = int(time.time()-start)
-                if vol.status != 'available':
-                    raise Exception("volume:"+str(vol.id)+", did not enter available state after terminating:"+str(self.id))
-                self.debug('Previously attached volume:'+str(vol.id)+" has gone to status:"+str(vol.status))
-            if bad_vols:
-                raise Exception("Check test code. Unsync'd volumes found before terminating:"+",".join(bad_vol_ids))
+                    vol.update()
+                    self.debug(str(self.id)+' terminated, waiting for attached volume:'+str(vol.id)+ ', status:'+str(vol.status))
+                    if vol.status == 'available':
+                        self.attached_vols.remove(vol)
+                if self.attached_vols and (elapsed < timeout):
+                        time.sleep(5)
+            
+            if self.attached_vols or bad_vols:
+                if bad_vols:
+                    bad_vol_error = 'ERROR: Unsynced volumes found prior to issuing terminate, check test code:'+",".join(bad_vol_ids)
+                if self.attached_vols:
+                    attached_vol_error += 'ERROR: Volumes did not become available after instance was terminated:'
+                    for vol in self.attached_vols:
+                        attached_vol_error += str(vol.id)+':'+str(vol.status)+", "                        
+                raise Exception(str(self.id)+", volume errors found during instance terminate:\n"+bad_vol_error+"\n"+attached_vol_error )
+                
                 
         
     def get_guestdevs_inuse_by_vols(self):
@@ -561,7 +575,7 @@ class EuInstance(Instance, TaggedResource):
                     in_use_cloud += str(vol.id)+", "
                     continue
             if inuse is False:
-                self.debug("Instance:"+str(self.id)+" returning available scsi dev:"+str(dev))
+                self.debug("Instance:"+str(self.id)+" returning available cloud scsi dev:"+str(dev))
                 return str(dev)
             else:
                 d = chr(ord('e') + x) #increment the letter we append to the device string prefix
@@ -578,7 +592,7 @@ class EuInstance(Instance, TaggedResource):
         fillcmd = "dd if=/dev/zero of="+str(voldev)+"; sync"
         return self.time_dd(fillcmd)
     
-    def random_fill_volume(self,euvolume,srcdev=None, length=None):
+    def random_fill_volume(self,euvolume,srcdev=None, length=None, timepergig=90):
         '''
         Attempts to fill the entie given euvolume with unique non-zero data.
         The srcdev is read from in a set size, and then used to write to the euvolume to populate it. The file 
@@ -589,12 +603,12 @@ class EuInstance(Instance, TaggedResource):
         :param length: the number of bytes to copy into the euvolume
         :returns dd's data/time stat
         '''
+        mb = 1048576
         gb = 1073741824 
         fsize = 10485760 #10mb
         if not euvolume in self.attached_vols:
             raise Exception(self.id+" Did not find this in instance's attached list. Can not write to this euvolume")
-        if not length:
-            length = euvolume.size * gb
+        
         voldev = euvolume.guestdev.strip()
         self.assertFilePresent(voldev)
         if srcdev is None:
@@ -604,23 +618,228 @@ class EuInstance(Instance, TaggedResource):
                 #look for the another large device we can read from in random size increments
                 srcdev = "/dev/"+str(self.sys("ls -1 /dev | grep 'da$'")[0]).strip()
                 fsize = randint(1048576,10485760)
+        if not length:
+            timeout = int(euvolume.size) * timepergig
+            return self.dd_monitor(ddif=str(srcdev), ddof=str(voldev), ddbs=bs,timeout=timeout)
+        else:
+            timeout = timepergig * ((length/gb) or 1) 
+            #write the volume id into the volume for starters
+            ddcmd = 'echo '+str(euvolume.id)+' | dd of='+str(voldev)
+            dd_res_for_id = self.dd_monitor(ddcmd=ddcmd, timeout=timeout)
+            len_remaining = length - int(dd_res_for_id['dd_bytes'])
+            if len_remaining <= length:
+                return dd_res_for_id
+            if length < mb:
+                return self.dd_monitor(ddif=str(srcdev), ddof=str(voldev), ddbs=length, ddseek=int(dd_res_for_id['dd_bytes']), timeout=timeout)
+            else:
+                return self.dd_monitor(ddif=str(srcdev), ddof=str(voldev), ddbytes=length, ddseek=int(dd_res_for_id['dd_bytes']), timeout=timeout)
                 
-        fillcmd = "head -c "+str(length)+" "+srcdev+" > "+voldev+"; echo "+str(euvolume.id)+" > " + str(voldev)+"; sync"
-
-        return self.time_dd(fillcmd)
+            
     
-    
-    def time_dd(self,ddcmd):
+    def time_dd(self,ddcmd, timeout=90, poll_interval=1, tmpfile=None):
         '''
-        Executes dd command on instance, parses and returns dd's data/time stat
+        (Added for legacy support, use dd_monitor instead) Executes dd command on instance, parses and returns stats on dd outcome
         '''
-        time=""
-        out = self.sys(ddcmd)
-        for line in out:
-            line = str(line)
-            if re.search('copied',line):
-                time=float(str(line.split(',').pop()).split()[0])
-        return time
+        return self.dd_monitor(ddcmd=ddcmd, poll_interval=poll_interval, tmpfile=tmpfile)
+        
+    def dd_monitor(self, ddif=None, ddof=None, ddcount=None, ddbs=1024, ddbytes=None, ddcmd=None, ddseek=None, timeout=300, poll_interval=1, tmpfile=None):
+        '''
+        Executes dd command on instance, monitors and displays ongoing status, and returns stats dict for dd outcome
+        :type ddif: str
+        :param ddif: Interface to read data in from
+        
+        :type ddof: str
+        :param ddof: Interface to write data to
+        
+        :type ddcount: int
+        :param ddcount: Number or count of block size (ddbs) to read/write
+        
+        :type ddbs: int
+        :param ddbs: Block size used for  reads/writes
+        
+        :type ddbytes: int
+        :param ddbytes: Number of bytes to be roughly read/write (note: used as ddbytes/ddbs = count) 
+        
+        :type ddcmd: str
+        :param ddcmd: String representing a preformed dd comand to be executed and monitored
+        
+        :type ddseek: int
+        :param ddseek: length of ddof file to seek before writing
+        
+        :type timeout: int
+        :param timeout: Number of seconds to wait before timing out on dd cmd. 
+        
+        :type poll_interval: int
+        :param poll_interval: Number of seconds to pause between polling dd and updating status
+        
+        :type tmpfile: str
+        :param tmpfile: temp file used on remote instance to redirect dd's stderr to in order to nohup dd. 
+        
+        :rtype: dict
+        :returns: dict containing dd stats
+        '''
+        
+        mb = 1048576 #bytes per mb
+        gig = 1073741824 #bytes per gig
+        #this tmp file will be created on remote instance to write stderr from dd to...
+        if not tmpfile:
+            tstamp = time.time()
+            tmpfile = '/tmp/eutesterddcmd.'+str(int(tstamp))
+        #init return dict 
+        ret = {
+               'dd_records_in' : 0,
+               'dd_records_out' : 0,
+               'dd_bytes' : 0,
+               'dd_mb' : 0,
+               'dd_gig' : 0,
+               'dd_elapsed' : 0,
+               'dd_rate' : 0,
+               'dd_units' : "",
+               'dd_full_rec_in' : 0,
+               'dd_full_rec_out' : 0,
+               'dd_partial_rec_in' : 0,
+               'dd_partial_rec_out' : 0,
+               'test_time' : 0,
+               'test_rate' : 0,
+               'ddcmd' : "" }
+        dd_units = 0
+        elapsed = 0
+        done = False
+        infobuf = None
+        start = time.time()
+        if ddcmd:
+            ddcmd = ddcmd
+        else:
+            if not ddif or not ddof:
+                raise Exception('dd_monitor needs ddif and ddof, or a preformed ddcmd string')
+            ddbs_str = str(' bs='+str(ddbs)+' ') or ""
+            if ddcount:
+                ddcount_str = str(' count='+str(ddcount)+' ')
+            elif ddbytes and ddbs:
+                ddcount_str = str(' count='+str(ddbytes/ddbs)+' ')
+            else:
+                ddcount_str = ''
+            if ddseek:
+                ddseek_str = str(' seek='+str(ddseek)+' ')
+            else:
+                 ddseek_str = ''
+            ddcmd = str('dd if='+str(ddif)+' of='+str(ddof)+str(ddseek_str)+str(ddbs_str)+str(ddcount_str))
+            ret['ddcmd'] = ddcmd
+        '''
+        Due to the ssh psuedo tty, this is done in an ugly manner to get output of future usr1 signals 
+        for dd status updates and allow this to run with nohup in the background. Added sleep so cmd is nohup'd 
+        before tty is terminated (maybe?)
+        '''
+        cmd = 'nohup '+str(ddcmd)+' 2> '+str(tmpfile)+' & echo $! && sleep 2'
+        #Execute dd command and store echo'd pid from output
+        dd_pid = self.sys(cmd)[0]
+        
+        #Form the table headers for printing dd status...
+        linediv = '\n----------------------------------------------------------------------------------------------------------------------------\n'
+        databuf = str('BYTES').ljust(15)
+        databuf += '|'+str('MBs').center(15)
+        databuf += '|'+str('GIGs').center(8)
+        
+        timebuf = '|'+str('DD TIME').center(10)
+        timebuf += '|'+str('TEST TIME').center(10)
+        
+        ratebuf = '|'+str('DD RATE').center(12)
+        ratebuf += '|'+str('TEST RATE').center(12)
+        
+        recbuf = '|'+str('REC_IN').center(18)
+        recbuf += '|'+str('REC_OUT').center(18)
+        
+        info_header = str('DD DATA INFO').ljust(len(databuf))
+        info_header += '|' + str('DD TIME INFO').center(len(timebuf)-1) 
+        info_header += '|' + str('DD RATE INFO').center(len(ratebuf)-1)
+        info_header += '|' + str('DD RECORDS FULL/PARTIAL INFO').center(len(recbuf)-1)
+        
+        buf = linediv
+        buf += info_header
+        buf += linediv
+        buf += databuf + timebuf + ratebuf + recbuf
+        buf += linediv
+        sys.stdout.write(buf)
+        sys.stdout.flush()
+        
+        #Keep getting and printing dd status until done...
+        while not done and (elapsed < timeout):
+            #send sig usr1 to have dd process dump status to stderr redirected to tmpfile
+            output = self.ssh.cmd('kill -USR1 '+str(dd_pid), verbose=False)
+            cmdstatus = int(output['status'])
+            if cmdstatus != 0:
+                done = True
+                #if the command returned error, process is done
+                out = self.sys('cat '+str(tmpfile)+"; rm -f "+str(tmpfile),code=0, verbose=False)
+            else:
+                #if the above command didn't error out then dd ps is still running, grab status from tmpfile, and clear it
+                out= self.sys('cat '+str(tmpfile)+" && echo '' > "+str(tmpfile)+ ' 2>&1 > /dev/null', code=0, verbose=False)
+            for line in out:
+                line = str(line)
+                try:
+                    if re.search('records in',line):
+                        ret['dd_records_in'] = str(line.split()[0]).strip()
+                        ret['dd_full_rec_in'] = str(ret['dd_records_in'].split("+")[0].strip())
+                        #dd_full_rec_in = int(dd_full_rec_in)
+                        ret['dd_partial_rec_in'] = str(ret['dd_records_in'].split("+")[1].strip())
+                        #dd_partial_rec_in = int(dd_partial_rec_in)
+                    elif re.search('records out', line):
+                        ret['dd_records_out'] = str(line.split()[0]).strip()
+                        ret['dd_full_rec_out'] = str(ret['dd_records_out'].split("+")[0].strip())
+                        #dd_ful_rec_out = int(dd_full_rec_out)
+                        ret['dd_partial_rec_out'] = str(ret['dd_records_out'].split("+")[1].strip())
+                        #dd_partial_rec_out = int(dd_partial_rec_out)
+                    elif re.search('copied',line):
+                        #123456789 bytes (123 MB) copied, 12.34 s, 123.45 MB/s
+                        summary = line.split()
+                        ret['dd_bytes'] = int(summary[0])
+                        ret['dd_mb'] = float("{0:.2f}".format(ret['dd_bytes']/float(mb)))
+                        ret['dd_gig'] = float("{0:.2f}".format(ret['dd_bytes']/float(gig)))
+                        ret['dd_elapsed'] = float(summary[5])
+                        ret['dd_rate'] = float(summary[7])
+                        ret['dd_units'] = str(summary[8])
+                except Exception, e:
+                    #catch any exception in the data parsing and show it as info/debug later...
+                    tb = self.tester.get_traceback()
+                    infobuf = '\n\nCaught exception while processing line:"'+str(line)+'"'
+                    infobuf += '\n'+str(tb)+"\n"+str(e)+'\n'
+            elapsed = float(time.time()-start)
+            ret['test_rate'] = float("{0:.2f}".format(ret['dd_mb'] / elapsed ))
+            ret['test_time'] = "{0:.4f}".format(elapsed)
+            #Create and format the status output buffer, then print it...
+            buf = str(ret['dd_bytes']).ljust(15)
+            buf += '|'+str(ret['dd_mb']).center(15)
+            buf += '|'+str(ret['dd_gig']).center(8)
+            buf += '|'+str(ret['dd_elapsed']).center(10)
+            buf += '|'+str(ret['test_time']).center(10)
+            buf += '|'+str(str(ret['dd_rate'])+" "+str(ret['dd_units'])).center(12)
+            buf += '|'+str(str(ret['test_rate'])+" "+str('MB/s')).center(12)
+            buf += '|'+str("F:"+str(ret['dd_full_rec_in'])+" P:"+str(ret['dd_partial_rec_in'])+" ").center(18)
+            buf += '|'+str("F:"+str(ret['dd_full_rec_out'])+" P:"+str(ret['dd_partial_rec_out'])).center(18)
+            sys.stdout.write("\r\x1b[K"+str(buf))
+            sys.stdout.flush()
+            time.sleep(poll_interval)
+        sys.stdout.write(linediv)
+        sys.stdout.flush()
+        elapsed = int(time.time()-start)
+        if not done:
+            #Attempt to kill dd process...
+            self.sys('kill '+str(dd_pid))
+            raise Exception('dd_monitor timed out before dd cmd completed, elapsed:'+str(elapsed)+'/'+str(timeout))
+        else:
+            #sync to ensure writes to dev
+            self.sys('sync', code=0)
+            elapsed = int(time.time()-start)
+        #if we have any info from exceptions caught during parsing, print that here...
+        if infobuf:
+            print infobuf
+        #if we didn't transfer any bytes of data, assume the cmd failed and wrote to stderr now in outbuf...
+        if not ret['dd_bytes']:
+            if out:
+                outbuf = "\n".join(out)
+            raise Exception('Did not transfer any data using dd cmd:'+str(ddcmd)+"\nstderr: "+str(outbuf))
+        self.debug('Done with dd, copied '+str(ret['dd_bytes'])+' over elapsed:'+str(elapsed))
+        return ret
     
     def vol_write_random_data_get_md5(self, euvolume, srcdev=None, length=32, timepergig=90, overwrite=False):
         '''
@@ -636,7 +855,8 @@ class EuInstance(Instance, TaggedResource):
         
         voldev = euvolume.guestdev.strip()  
         #check to see if there's existing data that we should avoid overwriting 
-        if overwrite or ( int(self.sys('head -c 32 '+str(voldev)+' | xargs -0 printf %s | wc -c')[0]) == 0):
+        if overwrite or ( int(self.sys('head -c '+str(length)+ ' '+str(voldev)+' | xargs -0 printf %s | wc -c')[0]) == 0):
+            
             self.random_fill_volume(euvolume, srcdev=srcdev, length=length)
         else:
             self.debug("Volume has existing data, skipping random data fill")
@@ -662,7 +882,7 @@ class EuInstance(Instance, TaggedResource):
         try:
             voldev = euvolume.guestdev
             timeout = euvolume.size * timepergig
-            md5 = self.get_dev_md5(voldev, length)
+            md5 = self.get_dev_md5(voldev, length,timeout)
             self.debug("Got MD5 for Volume:"+euvolume.id+" dev:"+voldev+" md5:"+md5)
             if updatevol:
                 euvolume.md5=md5
@@ -688,7 +908,7 @@ class EuInstance(Instance, TaggedResource):
         checkvolstatus - optional -boolean to be used to check volume status post start up
         '''
         msg=""
-        self.debug('Attempting to reboot instance:'+str(self.id))
+        self.debug('Attempting to reboot instance:'+str(self.id)+', check attached volume state first')
         uptime = int(self.sys('cat /proc/uptime')[0].split()[1].split('.')[0])
         elapsed = 0
         start = time.time()
@@ -699,6 +919,7 @@ class EuInstance(Instance, TaggedResource):
                 for bv in bad_vols:
                     self.debug(str(self.id)+'Unsynced volume found:'+str(bv.id))
                 raise Exception(str(self.id)+"Could not reboot using checkvolstatus flag due to unsync'd volumes")
+        self.debug('Rebooting now...')
         self.reboot()
         time.sleep(waitconnect)
         self.connect_to_instance(timeout=timeout)
@@ -717,20 +938,39 @@ class EuInstance(Instance, TaggedResource):
         
         
     def attach_euvolume_list(self,list,intervoldelay=0, timepervol=90, md5len=32):
+        '''
+        Attempts to attach a list of euvolumes. Due to limitations with KVM and detecting the location/device
+        name of the volume as attached on the guest, MD5 sums are used... 
+        -If volumes contain an md5 will wait intervoldelay seconds
+        before attempting to attach the next volume in the list. 
+        -If the next volume in the list does not have an MD5, the next volume will not be attached until
+        this volume is detected and an md5sum is populated in the euvolume. 
+        
+        :param list: List of volumes to be attached, if volumes are not of type euvolume they will be converted
+        :param intervoldelay : integer representing seconds between each volume attach attempt
+        :param timepervol: time to wait for volume to attach before failing
+        :param md5len: length from head of block device to read when calculating md5
+        
+        '''
         for euvol in list:
-            if not isinstance(euvol, EuVolume) or not euvol.md5:
-                raise Exception("Volumes in list must be of type EuVolume containing an accurate populated md5sum")
+            if not isinstance(euvol, EuVolume): # or not euvol.md5:
+                list[list.index(euvol)] = EuVolume.make_euvol_from_vol(euvol, self.tester)
         for euvol in list:
             dev = self.get_free_scsi_dev()
-            if (self.tester.attach_volume(self, euvolume, dev, pause=10,timeout=timeout)):
-                self.attached_vols.append(euvol)
+            if euvol.md5:
+                #Monitor volume to attached, dont write/read head for md5 use existing. Check md5 sum later in get_unsynced_volumes. 
+                if (self.tester.attach_volume(self, euvolume, dev, pause=10,timeout=timepervol)):
+                    self.attached_vols.append(euvol)
+                else:
+                    raise Exception('attach_euvolume_list: Test Failed to attach volume:'+str(euvolume.id))
             else:
-                raise Exception('attach_euvolume_list: Test Failed to attach volume:'+str(euvolume.id))
-            if delay:
+                #monitor volume to attached and write unique string to head and record it's md5sum 
+                self.attach_euvolume(euvol, dev, timeout=timepervol)
+            if intervoldelay:
                 time.sleep(intervoldelay)
         start = time.time()
         elapsed = 0 
-        badvols = self.get_unsynced_volumes(euvol_list, md5length=md5length, timepervol=timepervol, check_md5=True)
+        badvols = self.get_unsynced_volumes(list, md5length=md5len, timepervol=timepervol, check_md5=True)
         if badvols:
             buf = ""
             for bv in badvols:
@@ -763,7 +1003,7 @@ class EuInstance(Instance, TaggedResource):
         found = False
 
         if euvol_list is not None:
-            vol_list.append(euvol_list)
+            vol_list.extend(euvol_list)
         else:
             vol_list = self.attached_vols
         self.debug("Checking for volumes whos state is not in sync with our instance's test state...")
