@@ -247,10 +247,12 @@ class EutesterTestUnit():
             desc = desc+"\n".join(ret)
         return desc
     
-    def run(self):
+    def run(self, eof=None):
         '''
         Description: Wrapper which attempts to run self.method and handle failures, record time.
         '''
+        if eof is None:
+            eof = self.eof
         for count, thing in enumerate(self.args):
             print 'ARG:{0}. {1}'.format(count, thing)
         for name, value in self.kwargs.items():
@@ -272,7 +274,7 @@ class EutesterTestUnit():
             print TestColor.get_canned_color('failred')+buf+TestColor.reset
             self.error = str(e)
             self.result = EutesterTestResult.failed
-            if self.eof:
+            if eof:
                 raise e
             else:
                 pass
@@ -283,10 +285,10 @@ class EutesterTestUnit():
 class EutesterTestCase(unittest.TestCase):
     color = TestColor()
 
-    def __init__(self,name=None, debugmethod=None, use_default_file=True, default_config='eutester.conf'):
-        return self.setuptestcase(name=name, debugmethod=debugmethod, use_default_file=use_default_file, default_config=default_config)
+    def __init__(self,name=None, debugmethod=None):
+        return self.setuptestcase(name=name, debugmethod=debugmethod)
         
-    def setuptestcase(self, name=None, debugmethod=None, use_default_file=True, default_config='eutester.conf' ):
+    def setuptestcase(self, name=None, debugmethod=None, use_default_file=False, default_config='eutester.conf' ):
         self.name = self._testMethodName = name 
         if not self.name:
             callerfilename=inspect.getouterframes(inspect.currentframe())[1][1]
@@ -518,13 +520,13 @@ class EutesterTestCase(unittest.TestCase):
         else:
             self.debugmethod("("+str(cur_method)+":"+str(lineno)+"): "+colorprefix+str(msg)+colorreset )
 
-    def run_test_list_by_name(self, list):
+    def run_test_list_by_name(self, list, eof=None):
         unit_list = []
         for test in list:
             unit_list.append( self.create_testunit_by_name(test) )
 
         ### Run the EutesterUnitTest objects
-        return self.run_test_case_list(unit_list)
+        return self.run_test_case_list(unit_list,eof=eof)
 
     def create_testunit_from_method(self,method, *args, **kwargs):
         '''
@@ -667,7 +669,7 @@ class EutesterTestCase(unittest.TestCase):
             buf += "---------------------\n"
         return buf
     
-    def run_test_case_list(self, list, eof=True, clean_on_exit=True, printresults=True):
+    def run_test_case_list(self, list, eof=False, clean_on_exit=True, printresults=True):
         '''
         Desscription: wrapper to execute a list of ebsTestCase objects
         
@@ -695,12 +697,12 @@ class EutesterTestCase(unittest.TestCase):
             for test in list:
                 tests_ran += 1
                 startbuf = ""
-                argbuf =self.get_pretty_args(test)
+                argbuf = self.get_pretty_args(test)
                 startbuf += str(test.description)+str(argbuf)
                 startbuf += 'Running list method: "'+str(self.print_testunit_method_arg_values(test))+'"'
                 self.startmsg(startbuf)
                 try:
-                    test.run()
+                    test.run(eof=eof or test.eof)
                 except Exception, e:
                     self.debug('Testcase:'+ str(test.name)+' error:'+str(e))
                     if eof or (not eof and test.eof):
@@ -820,7 +822,7 @@ class EutesterTestCase(unittest.TestCase):
     
     
     def clean_method(self):
-        raise Exception("Clean_method needs not implemented. Was run_list using clean_on_exit?")
+        raise Exception("Clean_method was not implemented. Was run_list using clean_on_exit?")
 
     def print_test_list_results(self,list=None, printout=True, printmethod=None):
         '''
@@ -975,6 +977,10 @@ class EutesterTestCase(unittest.TestCase):
         '''
         eof=False
         autoarg=True
+        obj = obj or self
+        meth = getattr(obj,name)
+        methvars = self.get_meth_arg_names(meth)
+
 
         
         #Pull out value relative to this method, leave in any that are intended to be passed through
@@ -993,12 +999,10 @@ class EutesterTestCase(unittest.TestCase):
                 obj = kwargs['obj']
             else:
                 obj = kwargs.pop('obj')
-                
-        obj = obj or self
-        meth = getattr(obj,name)
-        methvars = self.get_meth_arg_names(meth)       
+
         testunit = EutesterTestUnit(meth, *args, **kwargs)
         testunit.eof = eof
+
         #if autoarg, auto populate testunit arguements from local testcase.args namespace values
         if autoarg:
             self.populate_testunit_with_args(testunit)
@@ -1031,7 +1035,8 @@ class EutesterTestCase(unittest.TestCase):
         cf = argparse.Namespace()
         
         
-        if self.use_default_file and self.default_config:
+        if (hasattr(self, 'use_default_file') and self.use_default_file) and \
+                (hasattr(self, 'use_default_config') and self.default_config):
             try:
                 configfiles.append(self.default_config)
             except Exception, e:
