@@ -25,7 +25,7 @@ class BFEBSBasics(InstanceBasics):
         if not self.reservation:
             self.reservation = self.tester.run_instance(keypair=self.keypair.name, group=self.group.name, zone=zone)
         for instance in self.reservation.instances:
-            self.volume = self.tester.create_volume(azone=self.zone, size=2)
+            self.volume = self.tester.create_volume(zone=self.zone, size=2)
             self.volume_device = instance.attach_volume(self.volume)
             instance.sys("curl " +  self.args.imgurl + " > " + self.volume_device, timeout=800)
             snapshot = self.tester.create_snapshot(self.volume.id)
@@ -43,9 +43,14 @@ class BFEBSBasics(InstanceBasics):
         except Exception,e:
             self.RegisterImage()
             self.image = self.tester.get_emi(root_device_type="ebs")
+        if not self.volume:
+            self.volume = self.tester.create_volume(zone=self.zone, size=2)
         if self.reservation:
             self.tester.terminate_instances(self.reservation)
         self.reservation = self.tester.run_instance(self.image,keypair=self.keypair.name, group=self.group.name, zone=zone)
+        ## Ensure that we can attach and use a volume
+        for instance in self.reservation.instances:
+            vol_dev = instance.attach_volume(self.volume)
         self.assertTrue(self.tester.stop_instances(self.reservation))
         for instance in self.reservation.instances:
             if instance.ip_address or instance.private_ip_address:
